function noop() { }
function run(fn) {
    return fn();
}
function blank_object() {
    return Object.create(null);
}
function run_all(fns) {
    fns.forEach(run);
}
function is_function(thing) {
    return typeof thing === 'function';
}
function safe_not_equal(a, b) {
    return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
}

function append(target, node) {
    target.appendChild(node);
}
function insert(target, node, anchor) {
    target.insertBefore(node, anchor || null);
}
function detach(node) {
    node.parentNode.removeChild(node);
}
function destroy_each(iterations, detaching) {
    for (let i = 0; i < iterations.length; i += 1) {
        if (iterations[i])
            iterations[i].d(detaching);
    }
}
function element(name) {
    return document.createElement(name);
}
function text(data) {
    return document.createTextNode(data);
}
function space() {
    return text(' ');
}
function empty() {
    return text('');
}
function listen(node, event, handler, options) {
    node.addEventListener(event, handler, options);
    return () => node.removeEventListener(event, handler, options);
}
function prevent_default(fn) {
    return function (event) {
        event.preventDefault();
        // @ts-ignore
        return fn.call(this, event);
    };
}
function stop_propagation(fn) {
    return function (event) {
        event.stopPropagation();
        // @ts-ignore
        return fn.call(this, event);
    };
}
function attr(node, attribute, value) {
    if (value == null)
        node.removeAttribute(attribute);
    else if (node.getAttribute(attribute) !== value)
        node.setAttribute(attribute, value);
}
function children(element) {
    return Array.from(element.childNodes);
}
function set_data(text, data) {
    data = '' + data;
    if (text.wholeText !== data)
        text.data = data;
}
function set_input_value(input, value) {
    input.value = value == null ? '' : value;
}
function custom_event(type, detail) {
    const e = document.createEvent('CustomEvent');
    e.initCustomEvent(type, false, false, detail);
    return e;
}

let current_component;
function set_current_component(component) {
    current_component = component;
}
function get_current_component() {
    if (!current_component)
        throw new Error(`Function called outside component initialization`);
    return current_component;
}
function onDestroy(fn) {
    get_current_component().$$.on_destroy.push(fn);
}
function createEventDispatcher() {
    const component = get_current_component();
    return (type, detail) => {
        const callbacks = component.$$.callbacks[type];
        if (callbacks) {
            // TODO are there situations where events could be dispatched
            // in a server (non-DOM) environment?
            const event = custom_event(type, detail);
            callbacks.slice().forEach(fn => {
                fn.call(component, event);
            });
        }
    };
}
function setContext(key, context) {
    get_current_component().$$.context.set(key, context);
}
function getContext(key) {
    return get_current_component().$$.context.get(key);
}

const dirty_components = [];
const binding_callbacks = [];
const render_callbacks = [];
const flush_callbacks = [];
const resolved_promise = Promise.resolve();
let update_scheduled = false;
function schedule_update() {
    if (!update_scheduled) {
        update_scheduled = true;
        resolved_promise.then(flush);
    }
}
function add_render_callback(fn) {
    render_callbacks.push(fn);
}
let flushing = false;
const seen_callbacks = new Set();
function flush() {
    if (flushing)
        return;
    flushing = true;
    do {
        // first, call beforeUpdate functions
        // and update components
        for (let i = 0; i < dirty_components.length; i += 1) {
            const component = dirty_components[i];
            set_current_component(component);
            update(component.$$);
        }
        dirty_components.length = 0;
        while (binding_callbacks.length)
            binding_callbacks.pop()();
        // then, once components are updated, call
        // afterUpdate functions. This may cause
        // subsequent updates...
        for (let i = 0; i < render_callbacks.length; i += 1) {
            const callback = render_callbacks[i];
            if (!seen_callbacks.has(callback)) {
                // ...so guard against infinite loops
                seen_callbacks.add(callback);
                callback();
            }
        }
        render_callbacks.length = 0;
    } while (dirty_components.length);
    while (flush_callbacks.length) {
        flush_callbacks.pop()();
    }
    update_scheduled = false;
    flushing = false;
    seen_callbacks.clear();
}
function update($$) {
    if ($$.fragment !== null) {
        $$.update();
        run_all($$.before_update);
        const dirty = $$.dirty;
        $$.dirty = [-1];
        $$.fragment && $$.fragment.p($$.ctx, dirty);
        $$.after_update.forEach(add_render_callback);
    }
}
const outroing = new Set();
let outros;
function group_outros() {
    outros = {
        r: 0,
        c: [],
        p: outros // parent group
    };
}
function check_outros() {
    if (!outros.r) {
        run_all(outros.c);
    }
    outros = outros.p;
}
function transition_in(block, local) {
    if (block && block.i) {
        outroing.delete(block);
        block.i(local);
    }
}
function transition_out(block, local, detach, callback) {
    if (block && block.o) {
        if (outroing.has(block))
            return;
        outroing.add(block);
        outros.c.push(() => {
            outroing.delete(block);
            if (callback) {
                if (detach)
                    block.d(1);
                callback();
            }
        });
        block.o(local);
    }
}
function create_component(block) {
    block && block.c();
}
function mount_component(component, target, anchor) {
    const { fragment, on_mount, on_destroy, after_update } = component.$$;
    fragment && fragment.m(target, anchor);
    // onMount happens before the initial afterUpdate
    add_render_callback(() => {
        const new_on_destroy = on_mount.map(run).filter(is_function);
        if (on_destroy) {
            on_destroy.push(...new_on_destroy);
        }
        else {
            // Edge case - component was destroyed immediately,
            // most likely as a result of a binding initialising
            run_all(new_on_destroy);
        }
        component.$$.on_mount = [];
    });
    after_update.forEach(add_render_callback);
}
function destroy_component(component, detaching) {
    const $$ = component.$$;
    if ($$.fragment !== null) {
        run_all($$.on_destroy);
        $$.fragment && $$.fragment.d(detaching);
        // TODO null out other refs, including component.$$ (but need to
        // preserve final state?)
        $$.on_destroy = $$.fragment = null;
        $$.ctx = [];
    }
}
function make_dirty(component, i) {
    if (component.$$.dirty[0] === -1) {
        dirty_components.push(component);
        schedule_update();
        component.$$.dirty.fill(0);
    }
    component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
}
function init(component, options, instance, create_fragment, not_equal, props, dirty = [-1]) {
    const parent_component = current_component;
    set_current_component(component);
    const prop_values = options.props || {};
    const $$ = component.$$ = {
        fragment: null,
        ctx: null,
        // state
        props,
        update: noop,
        not_equal,
        bound: blank_object(),
        // lifecycle
        on_mount: [],
        on_destroy: [],
        before_update: [],
        after_update: [],
        context: new Map(parent_component ? parent_component.$$.context : []),
        // everything else
        callbacks: blank_object(),
        dirty
    };
    let ready = false;
    $$.ctx = instance
        ? instance(component, prop_values, (i, ret, ...rest) => {
            const value = rest.length ? rest[0] : ret;
            if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                if ($$.bound[i])
                    $$.bound[i](value);
                if (ready)
                    make_dirty(component, i);
            }
            return ret;
        })
        : [];
    $$.update();
    ready = true;
    run_all($$.before_update);
    // `false` as a special case of no DOM component
    $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
    if (options.target) {
        if (options.hydrate) {
            const nodes = children(options.target);
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.l(nodes);
            nodes.forEach(detach);
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            $$.fragment && $$.fragment.c();
        }
        if (options.intro)
            transition_in(component.$$.fragment);
        mount_component(component, options.target, options.anchor);
        flush();
    }
    set_current_component(parent_component);
}
class SvelteComponent {
    $destroy() {
        destroy_component(this, 1);
        this.$destroy = noop;
    }
    $on(type, callback) {
        const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
        callbacks.push(callback);
        return () => {
            const index = callbacks.indexOf(callback);
            if (index !== -1)
                callbacks.splice(index, 1);
        };
    }
    $set() {
        // overridden by instance, if it has props
    }
}

const getClient = (key, overrides = {}) => {
  if (typeof Firstclasspostcodes !== 'undefined') {
    return Firstclasspostcodes(key, overrides);
  }
  throw new Error(`
    Missing Firstclasspostcodes JS library.
    See: https://github.com/firstclasspostcodes/firstclasspostcodes-js
  `);
};

const getTarget = (target) => {
  if (!target) {
    return null;
  }
  if (typeof target === 'string') {
    return document.querySelector(target);
  }
  return target;
};

const assignValueToTarget = (target, value) => {
  const element = getTarget(target);
  if (!element) {
    // eslint-disable-next-line no-console
    return console.warn(`Error assigning value "${value}" to "${target}" (target not found)`);
  }
  element.value = value;
};

/* lib/PostcodeLookup/Input.svelte generated by Svelte v3.24.0 */

function get_each_context(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[9] = list[i];
	return child_ctx;
}

// (45:2) {#if completions && completions.length > 0}
function create_if_block(ctx) {
	let datalist;
	let each_value = /*completions*/ ctx[2];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block(get_each_context(ctx, each_value, i));
	}

	return {
		c() {
			datalist = element("datalist");

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			attr(datalist, "id", "autocomplete");
		},
		m(target, anchor) {
			insert(target, datalist, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(datalist, null);
			}
		},
		p(ctx, dirty) {
			if (dirty & /*completions*/ 4) {
				each_value = /*completions*/ ctx[2];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(datalist, null);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}
		},
		d(detaching) {
			if (detaching) detach(datalist);
			destroy_each(each_blocks, detaching);
		}
	};
}

// (47:4) {#each completions as completion}
function create_each_block(ctx) {
	let option;
	let t_value = /*completion*/ ctx[9] + "";
	let t;
	let option_value_value;

	return {
		c() {
			option = element("option");
			t = text(t_value);
			option.__value = option_value_value = /*completion*/ ctx[9];
			option.value = option.__value;
		},
		m(target, anchor) {
			insert(target, option, anchor);
			append(option, t);
		},
		p(ctx, dirty) {
			if (dirty & /*completions*/ 4 && t_value !== (t_value = /*completion*/ ctx[9] + "")) set_data(t, t_value);

			if (dirty & /*completions*/ 4 && option_value_value !== (option_value_value = /*completion*/ ctx[9])) {
				option.__value = option_value_value;
				option.value = option.__value;
			}
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

function create_fragment(ctx) {
	let div;
	let label;
	let t0;
	let label_class_value;
	let t1;
	let input;
	let input_class_value;
	let t2;
	let t3;
	let button;
	let t4;
	let button_class_value;
	let div_class_value;
	let mounted;
	let dispose;
	let if_block = /*completions*/ ctx[2] && /*completions*/ ctx[2].length > 0 && create_if_block(ctx);

	return {
		c() {
			div = element("div");
			label = element("label");
			t0 = text("Postcode Lookup");
			t1 = space();
			input = element("input");
			t2 = space();
			if (if_block) if_block.c();
			t3 = space();
			button = element("button");
			t4 = text("Lookup");
			attr(label, "class", label_class_value = /*classNames*/ ctx[1].label);
			attr(label, "for", "postcode-lookup-input");
			attr(input, "id", "postcode-lookup-input");
			attr(input, "list", "autocomplete");
			attr(input, "class", input_class_value = /*classNames*/ ctx[1].input);
			attr(input, "placeholder", "Enter your postcode");
			attr(input, "type", "text");
			attr(button, "class", button_class_value = /*classNames*/ ctx[1].button);
			attr(button, "type", "submit");
			attr(div, "data-testid", "container");
			attr(div, "class", div_class_value = /*classNames*/ ctx[1].container);
		},
		m(target, anchor) {
			insert(target, div, anchor);
			append(div, label);
			append(label, t0);
			append(div, t1);
			append(div, input);
			set_input_value(input, /*value*/ ctx[0]);
			append(div, t2);
			if (if_block) if_block.m(div, null);
			append(div, t3);
			append(div, button);
			append(button, t4);

			if (!mounted) {
				dispose = [
					listen(input, "input", /*input_input_handler*/ ctx[6]),
					listen(button, "click", stop_propagation(prevent_default(/*handleClick*/ ctx[3])))
				];

				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (dirty & /*classNames*/ 2 && label_class_value !== (label_class_value = /*classNames*/ ctx[1].label)) {
				attr(label, "class", label_class_value);
			}

			if (dirty & /*classNames*/ 2 && input_class_value !== (input_class_value = /*classNames*/ ctx[1].input)) {
				attr(input, "class", input_class_value);
			}

			if (dirty & /*value*/ 1 && input.value !== /*value*/ ctx[0]) {
				set_input_value(input, /*value*/ ctx[0]);
			}

			if (/*completions*/ ctx[2] && /*completions*/ ctx[2].length > 0) {
				if (if_block) {
					if_block.p(ctx, dirty);
				} else {
					if_block = create_if_block(ctx);
					if_block.c();
					if_block.m(div, t3);
				}
			} else if (if_block) {
				if_block.d(1);
				if_block = null;
			}

			if (dirty & /*classNames*/ 2 && button_class_value !== (button_class_value = /*classNames*/ ctx[1].button)) {
				attr(button, "class", button_class_value);
			}

			if (dirty & /*classNames*/ 2 && div_class_value !== (div_class_value = /*classNames*/ ctx[1].container)) {
				attr(div, "class", div_class_value);
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div);
			if (if_block) if_block.d();
			mounted = false;
			run_all(dispose);
		}
	};
}

function instance($$self, $$props, $$invalidate) {
	let { value = "" } = $$props;
	let { classNames = {} } = $$props;
	let { onLookup = () => null } = $$props;
	let { getClient = getContext("client") } = $$props;
	let response;
	let completions;

	const getAutocompletions = async () => {
		$$invalidate(2, completions = null);

		if (!value || value.length < 2) {
			return false;
		}

		response = await getClient().getAutocomplete(value);

		if (!response.isCompleted) {
			$$invalidate(2, completions = response.listCompletions());
			return;
		}

		const [[postcode]] = response;
		onLookup(postcode);
	};

	const handleClick = () => onLookup(value);

	function input_input_handler() {
		value = this.value;
		$$invalidate(0, value);
	}

	$$self.$set = $$props => {
		if ("value" in $$props) $$invalidate(0, value = $$props.value);
		if ("classNames" in $$props) $$invalidate(1, classNames = $$props.classNames);
		if ("onLookup" in $$props) $$invalidate(4, onLookup = $$props.onLookup);
		if ("getClient" in $$props) $$invalidate(5, getClient = $$props.getClient);
	};

	$$self.$$.update = () => {
		if ($$self.$$.dirty & /*value*/ 1) {
			 (getAutocompletions());
		}
	};

	return [
		value,
		classNames,
		completions,
		handleClick,
		onLookup,
		getClient,
		input_input_handler
	];
}

class Input extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance, create_fragment, safe_not_equal, {
			value: 0,
			classNames: 1,
			onLookup: 4,
			getClient: 5
		});
	}
}

/* lib/PostcodeLookup/Select.svelte generated by Svelte v3.24.0 */

function get_each_context$1(ctx, list, i) {
	const child_ctx = ctx.slice();
	child_ctx[4] = list[i][0];
	child_ctx[5] = list[i][1];
	return child_ctx;
}

// (19:4) {:else}
function create_else_block(ctx) {
	let option;

	return {
		c() {
			option = element("option");
			option.textContent = "No addresses found";
			option.__value = "No addresses found";
			option.value = option.__value;
		},
		m(target, anchor) {
			insert(target, option, anchor);
		},
		p: noop,
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

// (14:4) {#if addresses && addresses.length > 0}
function create_if_block$1(ctx) {
	let option;
	let each_1_anchor;
	let each_value = /*addresses*/ ctx[0];
	let each_blocks = [];

	for (let i = 0; i < each_value.length; i += 1) {
		each_blocks[i] = create_each_block$1(get_each_context$1(ctx, each_value, i));
	}

	return {
		c() {
			option = element("option");
			option.textContent = "Choose address...";

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].c();
			}

			each_1_anchor = empty();
			option.selected = true;
			option.disabled = true;
			option.__value = "Choose address...";
			option.value = option.__value;
		},
		m(target, anchor) {
			insert(target, option, anchor);

			for (let i = 0; i < each_blocks.length; i += 1) {
				each_blocks[i].m(target, anchor);
			}

			insert(target, each_1_anchor, anchor);
		},
		p(ctx, dirty) {
			if (dirty & /*addresses*/ 1) {
				each_value = /*addresses*/ ctx[0];
				let i;

				for (i = 0; i < each_value.length; i += 1) {
					const child_ctx = get_each_context$1(ctx, each_value, i);

					if (each_blocks[i]) {
						each_blocks[i].p(child_ctx, dirty);
					} else {
						each_blocks[i] = create_each_block$1(child_ctx);
						each_blocks[i].c();
						each_blocks[i].m(each_1_anchor.parentNode, each_1_anchor);
					}
				}

				for (; i < each_blocks.length; i += 1) {
					each_blocks[i].d(1);
				}

				each_blocks.length = each_value.length;
			}
		},
		d(detaching) {
			if (detaching) detach(option);
			destroy_each(each_blocks, detaching);
			if (detaching) detach(each_1_anchor);
		}
	};
}

// (16:6) {#each addresses as [value, text]}
function create_each_block$1(ctx) {
	let option;
	let t_value = /*text*/ ctx[5] + "";
	let t;
	let option_value_value;

	return {
		c() {
			option = element("option");
			t = text(t_value);
			option.__value = option_value_value = /*value*/ ctx[4];
			option.value = option.__value;
		},
		m(target, anchor) {
			insert(target, option, anchor);
			append(option, t);
		},
		p(ctx, dirty) {
			if (dirty & /*addresses*/ 1 && t_value !== (t_value = /*text*/ ctx[5] + "")) set_data(t, t_value);

			if (dirty & /*addresses*/ 1 && option_value_value !== (option_value_value = /*value*/ ctx[4])) {
				option.__value = option_value_value;
				option.value = option.__value;
			}
		},
		d(detaching) {
			if (detaching) detach(option);
		}
	};
}

function create_fragment$1(ctx) {
	let div;
	let label;
	let t0;
	let label_class_value;
	let t1;
	let select;
	let select_class_value;
	let div_class_value;
	let mounted;
	let dispose;

	function select_block_type(ctx, dirty) {
		if (/*addresses*/ ctx[0] && /*addresses*/ ctx[0].length > 0) return create_if_block$1;
		return create_else_block;
	}

	let current_block_type = select_block_type(ctx);
	let if_block = current_block_type(ctx);

	return {
		c() {
			div = element("div");
			label = element("label");
			t0 = text("Select your address");
			t1 = space();
			select = element("select");
			if_block.c();
			attr(label, "class", label_class_value = /*classNames*/ ctx[1].label);
			attr(label, "for", "select-address");
			attr(select, "class", select_class_value = /*classNames*/ ctx[1].select);
			attr(select, "id", "select-address");
			attr(div, "data-testid", "container");
			attr(div, "class", div_class_value = /*classNames*/ ctx[1].container);
		},
		m(target, anchor) {
			insert(target, div, anchor);
			append(div, label);
			append(label, t0);
			append(div, t1);
			append(div, select);
			if_block.m(select, null);

			if (!mounted) {
				dispose = listen(select, "change", stop_propagation(prevent_default(/*onChange*/ ctx[2])));
				mounted = true;
			}
		},
		p(ctx, [dirty]) {
			if (dirty & /*classNames*/ 2 && label_class_value !== (label_class_value = /*classNames*/ ctx[1].label)) {
				attr(label, "class", label_class_value);
			}

			if (current_block_type === (current_block_type = select_block_type(ctx)) && if_block) {
				if_block.p(ctx, dirty);
			} else {
				if_block.d(1);
				if_block = current_block_type(ctx);

				if (if_block) {
					if_block.c();
					if_block.m(select, null);
				}
			}

			if (dirty & /*classNames*/ 2 && select_class_value !== (select_class_value = /*classNames*/ ctx[1].select)) {
				attr(select, "class", select_class_value);
			}

			if (dirty & /*classNames*/ 2 && div_class_value !== (div_class_value = /*classNames*/ ctx[1].container)) {
				attr(div, "class", div_class_value);
			}
		},
		i: noop,
		o: noop,
		d(detaching) {
			if (detaching) detach(div);
			if_block.d();
			mounted = false;
			dispose();
		}
	};
}

function instance$1($$self, $$props, $$invalidate) {
	let { addresses } = $$props;
	let { classNames = {} } = $$props;
	let { onSelected = () => null } = $$props;
	const onChange = e => onSelected(e.target.value);

	$$self.$set = $$props => {
		if ("addresses" in $$props) $$invalidate(0, addresses = $$props.addresses);
		if ("classNames" in $$props) $$invalidate(1, classNames = $$props.classNames);
		if ("onSelected" in $$props) $$invalidate(3, onSelected = $$props.onSelected);
	};

	return [addresses, classNames, onChange, onSelected];
}

class Select extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$1, create_fragment$1, safe_not_equal, {
			addresses: 0,
			classNames: 1,
			onSelected: 3
		});
	}
}

/* lib/PostcodeLookup/index.svelte generated by Svelte v3.24.0 */

function create_if_block$2(ctx) {
	let select;
	let current;

	select = new Select({
			props: {
				classNames: /*classNames*/ ctx[2].select,
				onSelected: /*handleSelected*/ ctx[3],
				addresses: /*response*/ ctx[0].listAddresses()
			}
		});

	return {
		c() {
			create_component(select.$$.fragment);
		},
		m(target, anchor) {
			mount_component(select, target, anchor);
			current = true;
		},
		p(ctx, dirty) {
			const select_changes = {};
			if (dirty & /*response*/ 1) select_changes.addresses = /*response*/ ctx[0].listAddresses();
			select.$set(select_changes);
		},
		i(local) {
			if (current) return;
			transition_in(select.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(select.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			destroy_component(select, detaching);
		}
	};
}

function create_fragment$2(ctx) {
	let input;
	let t;
	let if_block_anchor;
	let current;

	input = new Input({
			props: {
				classNames: /*classNames*/ ctx[2].input,
				onLookup: /*handleLookup*/ ctx[4]
			}
		});

	let if_block = !/*target*/ ctx[1] && /*response*/ ctx[0] && create_if_block$2(ctx);

	return {
		c() {
			create_component(input.$$.fragment);
			t = space();
			if (if_block) if_block.c();
			if_block_anchor = empty();
		},
		m(target, anchor) {
			mount_component(input, target, anchor);
			insert(target, t, anchor);
			if (if_block) if_block.m(target, anchor);
			insert(target, if_block_anchor, anchor);
			current = true;
		},
		p(ctx, [dirty]) {
			if (!/*target*/ ctx[1] && /*response*/ ctx[0]) {
				if (if_block) {
					if_block.p(ctx, dirty);

					if (dirty & /*target, response*/ 3) {
						transition_in(if_block, 1);
					}
				} else {
					if_block = create_if_block$2(ctx);
					if_block.c();
					transition_in(if_block, 1);
					if_block.m(if_block_anchor.parentNode, if_block_anchor);
				}
			} else if (if_block) {
				group_outros();

				transition_out(if_block, 1, 1, () => {
					if_block = null;
				});

				check_outros();
			}
		},
		i(local) {
			if (current) return;
			transition_in(input.$$.fragment, local);
			transition_in(if_block);
			current = true;
		},
		o(local) {
			transition_out(input.$$.fragment, local);
			transition_out(if_block);
			current = false;
		},
		d(detaching) {
			destroy_component(input, detaching);
			if (detaching) detach(t);
			if (if_block) if_block.d(detaching);
			if (detaching) detach(if_block_anchor);
		}
	};
}

function instance$2($$self, $$props, $$invalidate) {
	const { selectTarget, classNames = {} } = getContext("style") || {};
	const dispatch = createEventDispatcher();
	let { getClient = getContext("client") } = $$props;
	let { response = null } = $$props;
	let address = null;
	let selectComponent;

	const unmountSelectComponent = () => {
		if (selectComponent) {
			selectComponent.$destroy();
		}
	};

	const handleSelected = value => {
		address = response.formatAddress(value);
		dispatch("address", address);
	};

	const handleLookup = async value => {
		$$invalidate(0, response = await getClient().getPostcode(value));

		if (target) {
			unmountSelectComponent();

			selectComponent = new Select({
					target,
					props: {
						onSelected: handleSelected,
						addresses: response.listAddresses()
					}
				});
		}
	};

	onDestroy(() => unmountSelectComponent());

	$$self.$set = $$props => {
		if ("getClient" in $$props) $$invalidate(5, getClient = $$props.getClient);
		if ("response" in $$props) $$invalidate(0, response = $$props.response);
	};

	let target;
	 $$invalidate(1, target = getTarget(selectTarget));
	return [response, target, classNames, handleSelected, handleLookup, getClient];
}

class PostcodeLookup extends SvelteComponent {
	constructor(options) {
		super();
		init(this, options, instance$2, create_fragment$2, safe_not_equal, { getClient: 5, response: 0 });
	}
}

/* lib/App.svelte generated by Svelte v3.24.0 */

function create_fragment$3(ctx) {
	let div;
	let postcodelookup;
	let div_class_value;
	let current;
	postcodelookup = new PostcodeLookup({});
	postcodelookup.$on("address", /*handleAddress*/ ctx[1]);

	return {
		c() {
			div = element("div");
			create_component(postcodelookup.$$.fragment);
			attr(div, "class", div_class_value = /*root*/ ctx[0].container);
		},
		m(target, anchor) {
			insert(target, div, anchor);
			mount_component(postcodelookup, div, null);
			current = true;
		},
		p: noop,
		i(local) {
			if (current) return;
			transition_in(postcodelookup.$$.fragment, local);
			current = true;
		},
		o(local) {
			transition_out(postcodelookup.$$.fragment, local);
			current = false;
		},
		d(detaching) {
			if (detaching) detach(div);
			destroy_component(postcodelookup);
		}
	};
}

function instance$3($$self, $$props, $$invalidate) {
	let { apiKey } = $$props;
	let { apiOverrides = {} } = $$props;
	let { style = {} } = $$props;

	let { addressTargets = {
		addressLine1: "[data-address-line1]",
		locality: "[data-address-locality]",
		county: "[data-address-county]",
		postcode: "[data-address-postcode]"
	} } = $$props;

	const dispatch = createEventDispatcher();
	setContext("style", style);
	setContext("client", () => getClient(apiKey, apiOverrides));
	const { classNames: { root = {} } = {} } = style;

	const handleAddress = ({ detail }) => {
		dispatch("address", detail);
		assignValueToTarget(addressTargets.addressLine1, detail.address);
		assignValueToTarget(addressTargets.locality, detail.locality);
		assignValueToTarget(addressTargets.county, detail.region);
		assignValueToTarget(addressTargets.postcode, detail.postcode);
	};

	$$self.$set = $$props => {
		if ("apiKey" in $$props) $$invalidate(2, apiKey = $$props.apiKey);
		if ("apiOverrides" in $$props) $$invalidate(3, apiOverrides = $$props.apiOverrides);
		if ("style" in $$props) $$invalidate(4, style = $$props.style);
		if ("addressTargets" in $$props) $$invalidate(5, addressTargets = $$props.addressTargets);
	};

	return [root, handleAddress, apiKey, apiOverrides, style, addressTargets];
}

class App extends SvelteComponent {
	constructor(options) {
		super();

		init(this, options, instance$3, create_fragment$3, safe_not_equal, {
			apiKey: 2,
			apiOverrides: 3,
			style: 4,
			addressTargets: 5
		});
	}
}

export default App;
